@@ -38,6 +38,7 @@ Marks
    Map
 """
 from warnings import warn
+import ipywidgets as widgets
 from ipywidgets import Widget, DOMWidget, CallbackDispatcher, Color, widget_serialization
 from traitlets import (
         Int, Unicode, List, Enum, Dict, Bool, Float, Instance, Tuple,
@@ -278,7 +279,7 @@ class Lines(Mark):
         of lines, the colors are reused.
     close_path: bool (default: False)
         Whether to close the paths or not.
-    fill: {'none', 'bottom', 'top', 'inside'}
+    fill: {'none', 'bottom', 'top', 'inside', 'between'}
         Fill in the area defined by the curves
     fill_colors: list of colors (default: [])
         Fill colors for the areas. Defaults to stroke-colors when no color provided.
@@ -358,7 +359,7 @@ class Lines(Mark):
                           'cardinal', 'cardinal-open', 'cardinal-closed', 'monotone', 'step-before', 'step-after'],
                          default_value='linear').tag(sync=True, display_name='Interpolation')
     close_path = Bool().tag(sync=True, display_name='Close path')
-    fill = Enum(['none', 'bottom', 'top', 'inside'], default_value='none').tag(sync=True, display_name='Fill')
+    fill = Enum(['none', 'bottom', 'top', 'inside', 'between'], default_value='none').tag(sync=True, display_name='Fill')
     marker = Enum(['circle', 'cross', 'diamond', 'square', 'triangle-down',
                    'triangle-up', 'arrow', 'rectangle', 'ellipse'],
                   default_value=None, allow_none=True).tag(sync=True,
@@ -1125,8 +1126,9 @@ class Map(Mark):
     hover_highlight: bool (default: True)
         boolean to control if the map should be aware of which country is being
         hovered on.
-    map_data: tuple (default: topoload("WorldMapData.json"))
-        tuple containing which map is to be displayed
+    map_data: dict (default: topo_load("map_data/WorldMap.json"))
+        a topojson-formatted dictionary with the objects to map under the key
+        'subunits'.
 
     Data Attributes
 
@@ -1426,3 +1428,38 @@ class Graph(Mark):
 
     _model_name = Unicode('GraphModel').tag(sync=True)
     _view_name = Unicode('Graph').tag(sync=True)
+
+
+@register_mark('bqplot.Image')
+class Image(Mark):
+    """Image mark, based on the ipywidgets image
+
+    If no scales are passed, uses the parent Figure scales.
+
+    Attributes
+    ----------
+    image: Instance of ipywidgets.Image
+        Image to be displayed
+
+    Data Attributes
+
+    x0: float or date or unicode (default: 0)
+        abscissa of the left-hand side of the image
+    x1: float or date or unicode (default: 1)
+        abscissa of the right-hand side of the image
+    y0: float or date or unicode (default: 0)
+        ordinate of the bottom of the image
+    y1: float or date or unicode (default: 1)
+        ordinate of the top of the image
+    """
+    _view_name = Unicode('Image').tag(sync=True)
+    _model_name = Unicode('ImageModel').tag(sync=True)
+    image = Instance(widgets.Image).tag(sync=True, **widget_serialization)
+    x0 = (Float(0.0) | Date() | Unicode()).tag(sync=True)
+    y0 = (Float(0.0) | Date() | Unicode()).tag(sync=True)
+    x1 = (Float(1.0) | Date() | Unicode()).tag(sync=True)
+    y1 = (Float(1.0) | Date() | Unicode()).tag(sync=True)
+    scales_metadata = Dict({
+        'x': {'orientation': 'horizontal', 'dimension': 'x'},
+        'y': {'orientation': 'vertical', 'dimension': 'y'},
+    }).tag(sync=True)
